@@ -445,7 +445,6 @@ class CatboostInterface(
         where user ids are the ones from received user_ids, and item_ids
         are the possible candidates for catboost ranker to rank.
         """
-        ...
 
     def pool(self, user_item_dataframe):
         """
@@ -750,7 +749,6 @@ class CatboostAggregatorRecommender(CatboostInterface):
         dataframe = self.set_index(dataframe, kind=self.FeatureKind.user_item)
         return dataframe
 
-    @Timer()
     @profile(log_every=10)
     def poll_fit_recommenders(
         self, users_explicit, user_ids
@@ -788,7 +786,7 @@ class CatboostAggregatorRecommender(CatboostInterface):
 
     @Timer()
     def aggregate_topk_recommendations(
-        self, users_explicit, user_ids, n_recommendations
+        self, users_explicit, user_ids, n_recommendations, minimum_n_candidates=100
     ):
         """
         Method to determine item recommendation candidates for each user during recommending.
@@ -798,18 +796,22 @@ class CatboostAggregatorRecommender(CatboostInterface):
         columns at index [user_id, item_id] are equal to rank of item_id in recommender's
         recommendations for user_id.
         """
+        topk = min(
+            self.n_items,
+            minimum_n_candidates + n_recommendations * len(self.fit_recommenders),
+        )
         recommenders_ranks = self.poll_fit_recommenders(
             user_ids=user_ids, users_explicit=users_explicit
         )
         items_reciprocal_ranks_sum = sum(
             [torch.where(i == -1, 0, 1 / i) for i in recommenders_ranks]
         )
-        _, topk_item_ids = items_reciprocal_ranks_sum.topk(k=n_recommendations, dim=1)
+        _, topk_item_ids = items_reciprocal_ranks_sum.topk(k=topk, dim=1)
         topk_ranks = [
             torch.take_along_dim(input=recommender_rank, indices=topk_item_ids, dim=1)
             for recommender_rank in recommenders_ranks
         ]
-        repeated_user_ids = einops.repeat(user_ids, f"u -> u {n_recommendations}")
+        repeated_user_ids = einops.repeat(user_ids, f"u -> u {topk}")
         topk_item_ids = einops.rearrange(topk_item_ids, "u k -> (u k)")
         topk_ranks = einops.rearrange(topk_ranks, "r u k -> (u k) r")
         dataframe = self.ranks_dataframe(
