@@ -13,11 +13,11 @@ import wandb
 
 from scipy.sparse import coo_matrix
 
-from ..utils import profile, prepare_artifact
+from my_recommending.utils import profile, prepare_artifact
 
 if TYPE_CHECKING:
     from my_tools.utils import SparseTensor
-    from .lit import LitRecommenderBase
+    from my_recommending.movielens.lit import LitRecommenderBase
 
 
 def csv_imdb_ratings_to_dataframe(
@@ -289,14 +289,17 @@ class MovieLens100k(MovieLensInterface):
 
 class MovieLens25m(MovieLensInterface):
     @profile()
-    def prepare_splits(self, train_time_quantile: float, test_user_fraction: float):
+    def prepare_splits(
+        self, train_time_quantile: float, test_user_fraction: float, seed=42
+    ):
         time_split_ante, time_split_post = dataframe_quantiles_deterministic_split(
             quantiles=[train_time_quantile, 1 - train_time_quantile],
             dataframe=self["ratings"],
             column_to_split_by="timestamp",
         )
         unique_user_ids = time_split_post["user_id"].unique()
-        test_user_ids = np.random.choice(
+        rng = np.random.default_rng(seed)
+        test_user_ids = rng.choice(
             unique_user_ids,
             size=int(len(unique_user_ids) * test_user_fraction),
             replace=False,
